
(_concepts)=
# Detailed Concepts

[Defining your Observation](observation)
: Information on how to define the observation

[The Forward Model](forward_model)
: How to create the forward model which simulates measurements from the observation

[The State Vector](state_vector)
: How the atmospheric state and retrieved properties are defined

[Measurement Vectors](measurement_vector)
: Information on measurement vectors

[Main Processing Class](processing)
: How the main processing orchestrator works

```{toctree}
:maxdepth: 4
:hidden:

observation.md
forward_model.md
state_vector.md
measurement_vector.md
processing.md

```
